'use strict';

// Load NPM modules

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = checkDispatch;
var hashKey = require('md5');
var circularJson = require('circular-json');

// Export
function checkDispatch() {
  var fatal = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

  // Track hash of last action
  var lastActionHash = '';
  // Declare functions
  var getHash = function getHash() {
    var action = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    return hashKey(circularJson.stringify(action));
  };
  var checkHash = function checkHash() {
    var action = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    return !(getHash(action) === lastActionHash);
  };
  var updateHash = function updateHash() {
    var action = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    return lastActionHash = getHash(action);
  };
  // Middleware
  return function (store) {
    return function (next) {
      return function (action) {
        if (checkHash(action)) {
          updateHash(action);
          return next(action);
        } else {
          // Define message
          var message = '[redux-duplicate-actions] A duplicate action has been detected. MORE INFO: ' + circularJson.stringify(action, null, 2);
          // Handle fatal or not?
          if (fatal) {
            throw new TypeError(message);
          } else {
            console.warn(message);
            return next(action);
          }
        }
      };
    };
  };
}